from setuptools import setup, find_packages

setup(
    name='Fcolor',
    version='0.2',
    description='Fcolor permet de facilement gerer les couleur rgb,hex et hsl',
    long_description='Fcolor représente un module Python offrant un accès à une palette de plus de 200 codes RGB. Il propose également deux fonctions permettant de convertir les valeurs RGB en format hexadécimal ou HSL (Teinte, Saturation, Luminosité), offrant ainsi une flexibilité étendue dans la manipulation des couleurs.',
    packages=find_packages(),
    install_requires=[

    ],
)